"""
Simago: Randomly generate populations.

"""


__version__ = "0.3.1"

__title__ = "simago"
__description__ = "Randomly generate populations."
__url__ = "https://github.com/alexanderharms/simago"
__uri__ = "https://github.com/alexanderharms/simago"
__doc__ = __description__ + " <" + __uri__ + ">"

__author__ = "Alexander Harms"
__email__ = "a.g.j.harms@protonmail.com"

__license__ = "GPL v3"
__copyright__ = "Copyright (c) 2020 Alexander Harms"
